# -*- coding: utf-8 -*-

import pytest
import smtplib
import datetime

from django.core.management import call_command
from django.utils import timezone as tz
from django.core.mail.backends.base import BaseEmailBackend

from crma.management.mailer import Mailer
from crma.models import EmailScheduler


@pytest.mark.usefixtures('db')
def test_send_mails(mailoutbox):
    call_command('loaddata', 'crma/tests/command_send_mails.yaml')

    def date_fn():
        return datetime.datetime(2015, 6, 15, 9, 14, tzinfo=tz.UTC)

    mailer = Mailer(date_fn)
    mailer()

    assert len(mailoutbox), 1


@pytest.mark.usefixtures('db')
def test_send_mails_not_ready(mailoutbox):
    call_command('loaddata', 'crma/tests/command_send_mails.yaml')

    def date_fn():
        return datetime.datetime(2015, 6, 15, 9, 12, tzinfo=tz.UTC)

    mailer = Mailer(date_fn)
    mailer()

    assert len(mailoutbox), 0


@pytest.mark.usefixtures('db')
def test_send_mails_mark_sent(mailoutbox):
    call_command('loaddata', 'crma/tests/command_send_mails.yaml')

    def date_fn():
        return datetime.datetime(2015, 6, 15, 9, 14, tzinfo=tz.UTC)

    mailer = Mailer(date_fn)
    mailer()

    es = EmailScheduler.objects.get(pk=1)
    assert es.status == 'sent'


class MockEmailBackend(BaseEmailBackend):
    def send_messages(self, email_messages):
        raise smtplib.SMTPRecipientsRefused(['john@example.org'])


@pytest.mark.usefixtures('db')
def test_send_mails_mark_error(settings, mailoutbox):
    settings.EMAIL_BACKEND = 'crma.tests.test_management_mailer.MockEmailBackend'
    call_command('loaddata', 'crma/tests/command_send_mails.yaml')

    def date_fn():
        return datetime.datetime(2015, 6, 15, 9, 14, tzinfo=tz.UTC)

    mailer = Mailer(date_fn)
    mailer()

    es = EmailScheduler.objects.get(pk=1)
    assert es.status == 'error'
    assert '''SMTPRecipientsRefused: ['john@example.org']''' in es.trace_error
