# -*- coding: utf-8 -*-

import pytest

from django.core.management import call_command

from crma.models import EmailScheduler, MailingList, Email, Contact


@pytest.mark.usefixtures('db')
def test_email_scheduler_get_subscription():
    call_command('loaddata', 'crma/tests/email_scheduler.yaml')
    es = EmailScheduler.objects.get(pk=1)
    s = es.get_subscription()
    assert s
    assert s.is_active


@pytest.mark.usefixtures('db')
def test_email_scheduler_extra_context():
    call_command('loaddata', 'crma/tests/email_scheduler.yaml')
    es = EmailScheduler.objects.get(pk=1)
    assert es.extra_context == {'abc': 'def'}


@pytest.mark.usefixtures('db')
def test_mailing_list_schedule_all():
    call_command('loaddata', 'crma/tests/email_scheduler.yaml')
    ml = MailingList.objects.get(pk=1)
    email = Email.objects.get(pk=2)

    count = ml.schedule(email)
    assert count == 2
    assert EmailScheduler.objects.filter(email=email).count() == 2


@pytest.mark.usefixtures('db')
def test_mailing_list_schedule():
    call_command('loaddata', 'crma/tests/email_scheduler.yaml')
    ml = MailingList.objects.get(pk=2)
    email = Email.objects.get(pk=2)

    count = ml.schedule(email)
    assert count == 1
    assert EmailScheduler.objects.filter(email=email).count() == 1


@pytest.mark.usefixtures('db')
def test_email_schedule():
    call_command('loaddata', 'crma/tests/email_scheduler.yaml')
    email = Email.objects.get(pk=2)
    contact = Contact.objects.get(pk=1)

    email.schedule(contact)
    assert EmailScheduler.objects.filter(email=email, contact=contact).count() == 1
