# -*- coding: utf-8 -*-

from django.views.generic.base import View, TemplateView, TemplateResponseMixin, RedirectView
from django.views.generic.detail import SingleObjectMixin
from django.core.urlresolvers import reverse
from django.http import Http404
from django.utils.crypto import constant_time_compare
from django.contrib.sites.shortcuts import get_current_site


from crma.models import (
    Subscription,
    EmailScheduler,
)
from crma.utils import decode_id
from crma.mails import MailBuilder


class UnsubscribeCompleted(TemplateView):
    template_name = 'crma/unsubscribe_completed.html'


class UnsubscribeView(SingleObjectMixin, RedirectView):
    permanent = False
    queryset = Subscription.objects
    slug_field = 'unsubscribe_key'
    slug_url_kwarg = 'key'

    def get_redirect_url(self, **kw):
        return reverse('crma_unsubscribe_completed')

    def get(self, request, *args, **kwargs):
        sub = self.get_object()
        sub.cancel()
        return super(UnsubscribeView, self).get(request, *args, **kwargs)


class ViewWebMail(SingleObjectMixin, TemplateResponseMixin, View):
    template_name = 'crma/mail_viewer.html'
    queryset = EmailScheduler.objects.all()
    pk_url_kwarg = 'scheduler_id'

    def get(self, request, *args, **kwargs):
        self.kwargs[self.pk_url_kwarg] = decode_id(self.kwargs[self.pk_url_kwarg])
        self.object = email_scheduler = self.get_object()

        # Create the related token to check that url token is valid
        token = email_scheduler.contact.generate_token()
        if not constant_time_compare(token, kwargs['scheduler_token']):
            raise Http404()

        site = get_current_site(self.request)
        mb = MailBuilder(email_scheduler, site)
        subject, body = mb.render_html()

        context = self.get_context_data(body=body, subject=subject)
        return self.render_to_response(context)
